@@ -166,10 +166,6 @@ int main(int argc, char *argv[])
     /**
      * enable high dpi support
      */
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    QCoreApplication::setAttribute(Qt::AA_UseHighDpiPixmaps, true);
-    QCoreApplication::setAttribute(Qt::AA_EnableHighDpiScaling, true);
-#endif
     QCoreApplication::setAttribute(Qt::AA_CompressHighFrequencyEvents, true);
 
     QApplication app(argc, argv);
